aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/Analysis/Passes.h
diff options
context:
space:
mode:
authorJeff Cohen <jeffc@jolt-lang.org>2005-01-10 03:56:27 +0000
committerJeff Cohen <jeffc@jolt-lang.org>2005-01-10 03:56:27 +0000
commit6e400f76e6921226ddacba367d3928474ed7567d (patch)
tree080a5fd6f08f1d65df1bbcc8eb27d13b8bcc9f8f /include/llvm/Analysis/Passes.h
parent68dc3109420f38d639fb2e9fed6f1a29df60795b (diff)
downloadexternal_llvm-6e400f76e6921226ddacba367d3928474ed7567d.zip
external_llvm-6e400f76e6921226ddacba367d3928474ed7567d.tar.gz
external_llvm-6e400f76e6921226ddacba367d3928474ed7567d.tar.bz2
Apply feed back from Chris:
1. Rename createLoaderPass to CreateProfileLoaderPass 2. Opt shouldn't use the pass registered in CodeGen. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@19431 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/Analysis/Passes.h')
-rw-r--r--include/llvm/Analysis/Passes.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/llvm/Analysis/Passes.h b/include/llvm/Analysis/Passes.h
index 47e1e72..771ac11 100644
--- a/include/llvm/Analysis/Passes.h
+++ b/include/llvm/Analysis/Passes.h
@@ -71,9 +71,10 @@ namespace llvm {
//===--------------------------------------------------------------------===//
//
// createLoaderPass - This pass loads information from a profile dump file.
//
- ModulePass *createLoaderPass();
+ ModulePass *createProfileLoaderPass();
//===--------------------------------------------------------------------===//
//
@@ -71,9 +71,10 @@ namespace llvm {
//===--------------------------------------------------------------------===//
//
- // createLoaderPass - This pass loads information from a profile dump file.
+ // createProfileLoaderPass - This pass loads information from a profile dump
+ // file.
//